==> haskell-system-filepath-0.4.14.1-78-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-filepath
version:              0.4.14.1
visibility:           public
id:                   system-filepath-0.4.14.1-L5mOhp70rg06GBurhYxv73
key:                  system-filepath-0.4.14.1-L5mOhp70rg06GBurhYxv73
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    High-level, byte-based file and directory path manipulations (deprecated).

category:             System
abi:                  ac8c0367cb11731df25458d57d31aa82
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-filepath
hs-libraries:         HSsystem-filepath-0.4.14.1-L5mOhp70rg06GBurhYxv73
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-system-filepath-0.4.14.1-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-system-filepath.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 system-filepath
version:              0.4.14.1
visibility:           public
id:                   system-filepath-0.4.14.1-IwEOuuOXe6yFKcHzP0isJO
key:                  system-filepath-0.4.14.1-IwEOuuOXe6yFKcHzP0isJO
license:              MIT
copyright:            John Millikin 2010-2012
maintainer:           https://github.com/fpco/haskell-filesystem
author:               John Millikin <jmillikin@gmail.com>
stability:            experimental
homepage:             https://github.com/fpco/haskell-filesystem
synopsis:
    High-level, byte-based file and directory path manipulations (deprecated)

description:
    High-level, byte-based file and directory path manipulations (deprecated).

category:             System
abi:                  a5f164368a4e3208227ff63d8ae39da4
exposed:              True
exposed-modules:
    Filesystem.Path Filesystem.Path.CurrentOS Filesystem.Path.Rules

hidden-modules:       Filesystem.Path.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/system-filepath-0.4.14.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-system-filepath
hs-libraries:         HSsystem-filepath-0.4.14.1-IwEOuuOXe6yFKcHzP0isJO
depends:
    base-4.17.2.1 bytestring-0.11.5.3 deepseq-1.4.8.0 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-system-filepath/html/system-filepath.haddock

haddock-html:         /usr/share/doc/haskell-system-filepath/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
